@@ -11,6 +11,9 @@ class ConfigBox(object):
             self.paths.append(path)
         self.config = hiyapyco.load(*args, **kwargs)
 
+    def __call__(self):
+        return self.config.get("configuration", None)
+
     def get_config_item(self, name: str) -> dict:
         configuration = self.config.get("configuration", None)
         if configuration is None:
